@@ -9,6 +9,7 @@
 
 ## Configuration
 # Commands
+$WGET = "/usr/bin/wget";
 $LYNX = "/usr/bin/lynx";
 #$SED = "/usr/bin/sed";
 $GREP = "/usr/bin/grep";
@@ -20,8 +21,9 @@ $pkgdatadir="$datadir/ktoblzcheck";
 $BANKDATADIR="${pkgdatadir}";
 
 ## Sanity checks
-die "lynx is not available on your system, or was not available on the system where the installed rpm was built. This tool requires lynx. If you have it installed, then edit the script and set the variable LYNX to the full path to lynx. Aborting for now."
-  if $LYNX eq "NO";
+die "Neither wget nor lynx is available on your system, or was available on the system where the installed rpm was built. This tool requires wget or lynx. If you have it i
+nstalled, then edit the script and set the variable WGET or LYNX to the full path to wget or lynx. Aborting for now."
+  if $WGET eq "NO" and $LYNX eq "NO";
 #die "sed or grep is not available on your system. This tool requires it. Aborting."
 #  if $SED eq "NO" || $GREP eq "NO";
 die "The directory for the bankdata \"$BANKDATADIR\" does not exist. Aborting."
@@ -39,10 +41,14 @@ $MAIN_DOC="$MAIN_URL/zahlungsverkehr_bankleitzahlen_download.php";
 $INSTALLED_NAME="bankdata.txt";
 
 if ($debug == 0) {
-  $LYNXCMD = "$LYNX -source $MAIN_DOC";
+  if ($WGET ne "NO") {
+    $DOWNLOADCMD = "$WGET -O - $MAIN_DOC";
+  } else {
+    $DOWNLOADCMD = "$LYNX -source $MAIN_DOC";
+  }
 } else {
   print "DEBUG MODE! Will only echo commands, not execute them.\n";
-  $LYNXCMD = "cat ~/privat/hbci/blabla.html";
+  $DOWNLOADCMD = "cat ~/privat/hbci/blabla.html";
 }
 # Old regexp before 2006-06-04
 #$datafile_regexp = 'blz\d{4,8}?pc\.txt';
@@ -52,7 +58,7 @@ $datafile_regexp = 'blz_\d{8}\.txt';
 ## Find the available potential download files
 @potential_files = ();
 @potential_urls = ();
-open(INPUT, "$LYNXCMD |") || die "can't open $LYNXCMD: $!";;
+open(INPUT, "$DOWNLOADCMD |") || die "can't open $DOWNLOADCMD: $!";;
 while (<INPUT>) {
   my ($addr) = m|($datafile_regexp)|giosx;
   if ($addr) {
@@ -131,8 +137,13 @@ if ($debug == 0) {
 ## Now the real work:
 ##
 ## 1. Download
-print "$ECHO $LYNX -source $download $gt $install_1\n";
-system("$ECHO $LYNX -source $download $gt $install_1");# || die "can't call system: $!";
+if ($WGET ne "NO") {
+  print "$ECHO $WGET -O $install_1 $download\n";
+  system("$ECHO $WGET -O $install_1 $download");
+} else {
+  print "$ECHO $LYNX -source $download $gt $install_1\n";
+  system("$ECHO $LYNX -source $download $gt $install_1");# || die "can't call system: $!";
+}
 
 ## 2. Check whether the Bundesbank's BLZ is in there
 print "$GREP -q 10000000 $install_1\n";
